@@ -482,7 +482,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """)
         ab.set_authors(("Mark Jenkins <mark@parit.ca>",
                         "Jamie Campbell <jamie@parit.ca>"))
-        ab.set_artists(("David Henry <david@parit.ca>",))
+        ab.set_artists(("David Henry <work@davidhenry.ca>",))
         ab.set_program_name("Bo-Keep")
         ab.set_logo( pixbuf_new_from_file_at_size(
                 bo_keep_logo_path, 300, 266) )
